@@ -1,9 +1,8 @@
 use clap::Parser;
-use colored::*;
 use istor::istor;
 
 const AUTHOR: &str = "@Octalbyte";
-const VERSION: &str = "0.1.0";
+const VERSION: &str = "0.2.0";
 
 #[derive(Parser, Debug)]
 #[clap(author, version, about, long_about = None)]
@@ -23,7 +22,7 @@ struct Args {
 fn main() {
     let args = Args::parse();
     if !args.quiet {
-        println!("isTor CLI v{} made by {}", VERSION.bold(), AUTHOR.bold());
+        println!("isTor CLI v{} made by {}", VERSION, AUTHOR);
     }
     println!("{}", istor::istor(args.ip.as_str(), args.connect));
 }
