@@ -1,50 +1,31 @@
 #[cfg(test)]
-mod tests {
+mod test;
 
-    use crate::istor;
-
-    #[test]
-    fn it_works() {
-        let result = 2 + 2;
-        assert_eq!(result, 4);
-    }
-
-    #[test]
-    fn test_all() {
-        assert_eq!(true, istor::istor("176.10.99.200", false)); //in the list
-        assert_eq!(false, istor::istor("176.10.99.300", false)); //not in the list
-        assert_eq!(false, istor::istor("176.10.99.200\n", false)); //in the list, but is not an ip
-        assert_eq!(true, istor::istor("95.143.193.125", false)); //in the list
-    }
-
-    #[test]
-    fn test_connect() {
-        assert_eq!(true, istor::istor("176.10.99.200", false)); //in the list
-        assert_eq!(false, istor::istor("176.10.99.300", false)); //not in the list
-        assert_eq!(false, istor::istor("176.10.99.200\n", false)); //in the list, but is not an ip
-        assert_eq!(true, istor::istor("95.143.193.125", false)); //in the list
-    }
-
-    #[test]
-    fn can_get_nodes() {
-        istor::get_nodes();
-    }
-
-    #[test]
-    fn can_connect() {
-        istor::get_nodes_real_time();
-    }
-}
 
 pub mod istor {
-    pub use ipaddress::IPAddress;
-    pub use std::collections::HashMap;
+
+    use ureq;
+
+    fn isvalid_ip(ip: String) -> bool {
+        if ip.contains("\n") {
+            return false;
+        }
+        let v: Vec<&str> = ip.split(".").collect();
+        if v[3] == "" {
+            return false;
+        }
+        if v.len() != 4 {
+            return false;
+        }
+        return true;
+    }
 
     pub fn get_nodes_real_time() -> String {
-        let resp = reqwest::blocking::get("https://check.torproject.org/torbulkexitlist")
-            .unwrap()
-            .text()
-            .unwrap();
+        let resp: String = ureq::get("https://check.torproject.org/torbulkexitlist")
+        .call()
+        .unwrap()
+        .into_string()
+        .unwrap();
         return resp;
     }
 
@@ -53,7 +34,7 @@ pub mod istor {
             false => get_nodes(),
             true => get_nodes_real_time(),
         };
-        if nodes.contains(&ip) && IPAddress::is_valid(String::from(ip)) {
+        if nodes.contains(&ip) &&  isvalid_ip(String::from(ip)) {
             return true;
         }
         return false;
